==> iTop-3.2.0-2-14758.zip: web/dictionaries/ui/pages/preferences/da.dictionary.itop.preferences.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('DA DA', 'Danish', 'Dansk', [
	'UI:Favorites:General:ShowSummaryCards' => 'Show summary cards~~',
	'UI:Favorites:General:ShowSummaryCards+' => 'When hovering an hyperlink targeting an object, display a short summary of the object, if available for that class~~',
	'UI:Preferences:ActivityPanel:EntryFormOpened' => 'Entry form opened by default~~',
	'UI:Preferences:ActivityPanel:EntryFormOpened+' => 'Whether the entry form will be opened when displaying an object. If unchecked, you will still be able to open it by clicking the compose button~~',
	'UI:Preferences:ActivityPanel:Title' => 'Activity panel~~',
	'UI:Preferences:ChooseAPlaceholder' => 'User placeholder image~~',
	'UI:Preferences:ChooseAPlaceholder+' => 'Choose a placeholder image that will be displayed if the contact linked to your user doesn\'t have one~~',
	'UI:Preferences:ChooseAPlaceholder:Success:Message' => 'Your placeholder image has been successfully updated~~',
	'UI:Preferences:General:Theme' => 'Theme~~',
	'UI:Preferences:General:Theme:DefaultThemeLabel' => '%1$s (default)~~',
	'UI:Preferences:General:Title' => 'General~~',
	'UI:Preferences:General:Toasts' => 'Toast notifications position~~',
	'UI:Preferences:General:Toasts:Bottom' => 'Bottom~~',
	'UI:Preferences:General:Toasts:Top' => 'Top~~',
	'UI:Preferences:Lists:Title' => 'Lists~~',
	'UI:Preferences:Notifications' => 'Notifications~~',
	'UI:Preferences:Notifications+' => 'Configure the notifications you want to receive <a href="%1$s">on this page</a>.~~',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset' => 'Reset~~',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset:Tooltip' => 'Back to default keyboard shortcut~~',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Tooltip' => 'Record a keyboard shortcut~~',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Input:Hint' => 'Type a keyboard shortcut~~',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Title' => 'Application keyboard shortcuts~~',
	'UI:Preferences:RichText:Title' => 'Rich text editor~~',
	'UI:Preferences:RichText:ToolbarState' => 'Toolbar default state~~',
	'UI:Preferences:RichText:ToolbarState:Collapsed' => 'Collapsed~~',
	'UI:Preferences:RichText:ToolbarState:Expanded' => 'Expanded~~',
	'UI:Preferences:Tabs:Layout:Horizontal' => 'Horizontal~~',
	'UI:Preferences:Tabs:Layout:Label' => 'Layout~~',
	'UI:Preferences:Tabs:Layout:Vertical' => 'Vertical~~',
	'UI:Preferences:Tabs:Scrollable:Classic' => 'Classic~~',
	'UI:Preferences:Tabs:Scrollable:Label' => 'Navigation~~',
	'UI:Preferences:Tabs:Scrollable:Scrollable' => 'Scrollable~~',
	'UI:Preferences:Tabs:Title' => 'Tabs~~',
	'UI:Preferences:Title' => 'Preferences~~',
	'UI:Preferences:UserInterface:Title' => 'User interface~~',
]);

==> iTop-3.2.2-1-17851.zip: web/dictionaries/ui/pages/preferences/da.dictionary.itop.preferences.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('DA DA', 'Danish', 'Dansk', array(
	'UI:Preferences:Title' => 'Preferences~~',
	'UI:Preferences:UserInterface:Title' => 'User interface~~',
	'UI:Preferences:General:Title' => 'General~~',
	'UI:Preferences:General:Theme' => 'Theme~~',
	'UI:Preferences:General:Theme:DefaultThemeLabel' => '%1$s (default)~~',
	'UI:Favorites:General:ShowSummaryCards' => 'Show summary cards~~',
	'UI:Favorites:General:ShowSummaryCards+' => 'When hovering an hyperlink targeting an object, display a short summary of the object, if available for that class~~',
	'UI:Preferences:Lists:Title' => 'Lists~~',
	'UI:Preferences:RichText:Title' => 'Rich text editor~~',
	'UI:Preferences:RichText:ToolbarState' => 'Toolbar default state~~',
	'UI:Preferences:RichText:ToolbarState:Expanded' => 'Expanded~~',
	'UI:Preferences:RichText:ToolbarState:Collapsed' => 'Collapsed~~',
	'UI:Preferences:ActivityPanel:Title' => 'Activity panel~~',
	'UI:Preferences:ActivityPanel:EntryFormOpened' => 'Entry form opened by default~~',
	'UI:Preferences:ActivityPanel:EntryFormOpened+' => 'Whether the entry form will be opened when displaying an object. If unchecked, you will still be able to open it by clicking the compose button~~',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Title' => 'Application keyboard shortcuts~~',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Input:Hint' => 'Type a keyboard shortcut~~',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Tooltip' => 'Record a keyboard shortcut~~',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset' => 'Reset~~',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset:Tooltip' => 'Back to default keyboard shortcut~~',
	'UI:Preferences:Tabs:Title' => 'Tabs~~',
	'UI:Preferences:Tabs:Layout:Label' => 'Layout~~',
	'UI:Preferences:Tabs:Layout:Horizontal' => 'Horizontal~~',
	'UI:Preferences:Tabs:Layout:Vertical' => 'Vertical~~',
	'UI:Preferences:Tabs:Scrollable:Label' => 'Navigation~~',
	'UI:Preferences:Tabs:Scrollable:Classic' => 'Classic~~',
	'UI:Preferences:Tabs:Scrollable:Scrollable' => 'Scrollable~~',
	'UI:Preferences:General:Toasts' => 'Toast notifications position~~',
	'UI:Preferences:General:Toasts:Bottom' => 'Bottom~~',
	'UI:Preferences:General:Toasts:Top' => 'Top~~',
	'UI:Preferences:ChooseAPlaceholder' => 'User placeholder image~~',
	'UI:Preferences:ChooseAPlaceholder+' => 'Choose a placeholder image that will be displayed if the contact linked to your user doesn\'t have one~~',
	'UI:Preferences:ChooseAPlaceholder:Success:Message' => 'Your placeholder image has been successfully updated~~',
	'UI:Preferences:Notifications' => 'Notifications~~',
	'UI:Preferences:Notifications+' => 'Configure the notifications you want to receive <a href="%1$s">on this page</a>.~~',
	
));
